.. _scanpipe_pipes:

Pipes
=====

Generic
-------
.. automodule:: scanpipe.pipes
    :members:

Codebase
--------
.. automodule:: scanpipe.pipes.codebase
    :members:

Compliance
----------
.. automodule:: scanpipe.pipes.compliance
    :members:

CycloneDX
---------
.. automodule:: scanpipe.pipes.cyclonedx
    :members:

Deploy to develop
-----------------
.. automodule:: scanpipe.pipes.d2d
    :members:

Docker
------
.. automodule:: scanpipe.pipes.docker
    :members:

Fetch
-----
.. automodule:: scanpipe.pipes.fetch
    :members:
    :exclude-members: Download

Input
-----
.. automodule:: scanpipe.pipes.input
    :members:

JVM
---
.. automodule:: scanpipe.pipes.jvm
    :members:

Output
------
.. automodule:: scanpipe.pipes.output
    :members:
    :exclude-members: JSONResultsGenerator

PurlDB
------
.. automodule:: scanpipe.pipes.purldb
    :members:

Resolve
-------
.. automodule:: scanpipe.pipes.resolve
    :members:

RootFS
------
.. automodule:: scanpipe.pipes.rootfs
    :members:

ScanCode
--------
.. automodule:: scanpipe.pipes.scancode
    :members:

SPDX
----
.. automodule:: scanpipe.pipes.spdx
    :members:

Flag
----
.. automodule:: scanpipe.pipes.flag
    :members:

VulnerableCode
--------------
.. automodule:: scanpipe.pipes.vulnerablecode
    :members:

Windows
-------
.. automodule:: scanpipe.pipes.windows
    :members:
